@@ -30,6 +30,7 @@ architecture section is not modified.
 #include <vector>
 #include <stdio.h>
 #include <map>
+#include <cstring>
 
 #include "faust/gui/meta.h"
 #include "faust/gui/UI.h"
@@ -217,8 +218,8 @@ class APIUI : public PathBuilder, public Meta, public UI
                 int id4 = getZoneIndex(table, p, val);
                 if (id4 != -1) {
                     // Reactivate the one we edit...
-                  table[val][uint(id4)]->setMappingValues(curve, amin, amid, amax, fItems[uint(p)].fMin, fItems[uint(p)].fInit, fItems[uint(p)].fMax);
-                  table[val][uint(id4)]->setActive(true);
+                    table[val][uint(id4)]->setMappingValues(curve, amin, amid, amax, fItems[uint(p)].fMin, fItems[uint(p)].fInit, fItems[uint(p)].fMax);
+                    table[val][uint(id4)]->setActive(true);
                 } else {
                     // Allocate a new CurveZoneControl which is 'active' by default
                     FAUSTFLOAT* zone = fItems[uint(p)].fZone;
@@ -366,20 +367,63 @@ class APIUI : public PathBuilder, public Meta, public UI
         //-------------------------------------------------------------------------------
         // Simple API part
         //-------------------------------------------------------------------------------
+    
+        /**
+         * Return the number of parameters in the UI.
+         *
+         * @return the number of parameters
+         */
         int getParamsCount() { return int(fItems.size()); }
 
-        int getParamIndex(const char* path_aux)
+        /**
+         * Return the param index.
+         *
+         * @param str - the UI parameter label/shortname/path
+         *
+         * @return the param index
+         */
+        int getParamIndex(const char* str)
         {
-            std::string path = std::string(path_aux);
+            std::string path = std::string(str);
             auto it = find_if(fItems.begin(), fItems.end(),
                               [=](const Item& it) { return (it.fLabel == path) || (it.fShortname == path) || (it.fPath == path); });
             return (it != fItems.end()) ? int(it - fItems.begin()) : -1;
         }
     
+        /**
+         * Return the param label.
+         *
+         * @param p - the UI parameter index
+         *
+         * @return the param label
+         */
         const char* getParamLabel(int p) { return fItems[uint(p)].fLabel.c_str(); }
+    
+        /**
+         * Return the param shortname.
+         *
+         * @param p - the UI parameter index
+         *
+         * @return the param shortname
+         */
         const char* getParamShortname(int p) { return fItems[uint(p)].fShortname.c_str(); }
+    
+        /**
+         * Return the param path.
+         *
+         * @param p - the UI parameter index
+         *
+         * @return the param path
+         */
         const char* getParamAddress(int p) { return fItems[uint(p)].fPath.c_str(); }
     
+        /**
+         * Return the param metadata.
+         *
+         * @param p - the UI parameter index
+         *
+         * @return the param metadata as a map<key, value>
+         */
         std::map<const char*, const char*> getMetadata(int p)
         {
             std::map<const char*, const char*> res;
@@ -390,30 +434,107 @@ class APIUI : public PathBuilder, public Meta, public UI
             return res;
         }
 
+        /**
+         * Return the param metadata value.
+         *
+         * @param p - the UI parameter index
+         * @param key - the UI parameter index
+         *
+         * @return the param metadata value associate to the key or nullptr if the key is not found
+         */
         const char* getMetadata(int p, const char* key)
         {
-            return (fMetaData[uint(p)].find(key) != fMetaData[uint(p)].end()) ? fMetaData[uint(p)][key].c_str() : "";
+            return (fMetaData[uint(p)].find(key) != fMetaData[uint(p)].end()) ? fMetaData[uint(p)][key].c_str() : nullptr;
         }
+    
+        /**
+         * Return the param minimum value.
+         *
+         * @param p - the UI parameter index
+         *
+         * @return the param minimum value
+         */
         FAUSTFLOAT getParamMin(int p) { return fItems[uint(p)].fMin; }
+    
+        /**
+         * Return the param maximum value.
+         *
+         * @param p - the UI parameter index
+         *
+         * @return the param maximum value
+         */
         FAUSTFLOAT getParamMax(int p) { return fItems[uint(p)].fMax; }
+    
+        /**
+         * Return the param step value.
+         *
+         * @param p - the UI parameter index
+         *
+         * @return the param step value
+         */
         FAUSTFLOAT getParamStep(int p) { return fItems[uint(p)].fStep; }
+    
+        /**
+         * Return the param init value.
+         *
+         * @param p - the UI parameter index
+         *
+         * @return the param init value
+         */
         FAUSTFLOAT getParamInit(int p) { return fItems[uint(p)].fInit; }
 
+        /**
+         * Return the param memory zone.
+         *
+         * @param p - the UI parameter index
+         *
+         * @return the param memory zone.
+         */
         FAUSTFLOAT* getParamZone(int p) { return fItems[uint(p)].fZone; }
 
+        /**
+         * Return the param value.
+         *
+         * @param p - the UI parameter index
+         *
+         * @return the param value.
+         */
         FAUSTFLOAT getParamValue(int p) { return *fItems[uint(p)].fZone; }
-        FAUSTFLOAT getParamValue(const char* path)
+    
+        /**
+         * Return the param value.
+         *
+         * @param str - the UI parameter label/shortname/path
+         *
+         * @return the param value.
+         */
+        FAUSTFLOAT getParamValue(const char* str)
         {
-            int index = getParamIndex(path);
+            int index = getParamIndex(str);
             if (index >= 0) {
                 return getParamValue(index);
             } else {
-                fprintf(stderr, "getParamValue : '%s' not found\n", (path == nullptr ? "NULL" : path));
+                fprintf(stderr, "getParamValue : '%s' not found\n", (str == nullptr ? "NULL" : str));
                 return FAUSTFLOAT(0);
             }
         }
 
+        /**
+         * Set the param value.
+         *
+         * @param p - the UI parameter index
+         * @param v - the UI parameter value
+         *
+         */
         void setParamValue(int p, FAUSTFLOAT v) { *fItems[uint(p)].fZone = v; }
+        
+        /**
+         * Set the param value.
+         *
+         * @param p - the UI parameter label/shortname/path
+         * @param v - the UI parameter value
+         *
+         */
         void setParamValue(const char* path, FAUSTFLOAT v)
         {
             int index = getParamIndex(path);
@@ -484,7 +605,7 @@ class APIUI : public PathBuilder, public Meta, public UI
          *
          * @param p - the UI parameter index
          * @param acc - 0 for X accelerometer, 1 for Y accelerometer, 2 for Z accelerometer (-1 means "no mapping")
-         * @param curve - between 0 and 3
+         * @param curve - between 0 and 3 (0: up, 1: down, 2: up and down, 2: down and up)
          * @param amin - mapping 'min' point
          * @param amid - mapping 'middle' point
          * @param amax - mapping 'max' point
@@ -500,7 +621,7 @@ class APIUI : public PathBuilder, public Meta, public UI
          *
          * @param p - the UI parameter index
          * @param gyr - 0 for X gyroscope, 1 for Y gyroscope, 2 for Z gyroscope (-1 means "no mapping")
-         * @param curve - between 0 and 3
+         * @param curve - between 0 and 3 (0: up, 1: down, 2: up and down, 2: down and up)
          * @param amin - mapping 'min' point
          * @param amid - mapping 'middle' point
          * @param amax - mapping 'max' point
@@ -516,7 +637,7 @@ class APIUI : public PathBuilder, public Meta, public UI
          *
          * @param p - the UI parameter index
          * @param acc - the acc value to be retrieved (-1 means "no mapping")
-         * @param curve - the curve value to be retrieved
+         * @param curve - the curve value to be retrieved (between 0 and 3)
          * @param amin - the amin value to be retrieved
          * @param amid - the amid value to be retrieved
          * @param amax - the amax value to be retrieved
@@ -532,7 +653,7 @@ class APIUI : public PathBuilder, public Meta, public UI
          *
          * @param p - the UI parameter index
          * @param gyr - the gyr value to be retrieved (-1 means "no mapping")
-         * @param curve - the curve value to be retrieved
+         * @param curve - the curve value to be retrieved (between 0 and 3)
          * @param amin - the amin value to be retrieved
          * @param amid - the amid value to be retrieved
          * @param amax - the amax value to be retrieved
@@ -581,8 +702,13 @@ class APIUI : public PathBuilder, public Meta, public UI
             return (gyr >= 0 && gyr < 3) ? int(fGyr[gyr].size()) : 0;
         }
 
-        // getScreenColor() : -1 means no screen color control (no screencolor metadata found)
-        // otherwise return 0x00RRGGBB a ready to use color
+        /**
+         * Get the requested screen color.
+         *
+         * -1 means no screen color control (no screencolor metadata found)
+         * otherwise return 0x00RRGGBB a ready to use color
+         *
+         */
         int getScreenColor()
         {
             if (fHasScreenControl) {
